summaryrefslogtreecommitdiffstats
path: root/krdc/kremoteview.h
diff options
context:
space:
mode:
Diffstat (limited to 'krdc/kremoteview.h')
-rw-r--r--krdc/kremoteview.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/krdc/kremoteview.h b/krdc/kremoteview.h
index a3dbe438..09b312c0 100644
--- a/krdc/kremoteview.h
+++ b/krdc/kremoteview.h
@@ -19,7 +19,7 @@
#define KREMOTEVIEW_H
-#include <qwidget.h>
+#include <tqwidget.h>
#include <kkeynative.h>
#include "events.h"
@@ -55,7 +55,7 @@ enum DotCursorState {
* maximum size to the remote size and minimum size to the
* smallest resolution that your scaler can handle.
* @li if you override mouseMoveEvent()
- * you must ignore the QEvent, because the KRDC widget will
+ * you must ignore the TQEvent, because the KRDC widget will
* need it for stuff like toolbar auto-hide and bump
* scrolling. If you use x11Event(), make sure that
* MotionNotify events will be forwarded.
@@ -65,7 +65,7 @@ class KRemoteView : public QWidget
{
Q_OBJECT
public:
- KRemoteView(QWidget *parent = 0,
+ KRemoteView(TQWidget *parent = 0,
const char *name = 0,
WFlags f = 0);
@@ -130,7 +130,7 @@ public:
/**
* Returns the resolution of the remote framebuffer.
* It should return a null @ref QSize when the size
* is not known.
* The backend must also emit a @ref changeSize()
* when the size of the framebuffer becomes available
@@ -138,7 +138,7 @@ public:
* @return the remote framebuffer size, a null QSize
* if unknown
*/
- virtual QSize framebufferSize() = 0;
+ virtual TQSize framebufferSize() = 0;
/**
* Initiate the disconnection. This doesn't need to happen
@@ -159,7 +159,7 @@ public:
* Returns the host the view is connected to.
* @return the host the view is connected to
*/
- virtual QString host() = 0;
+ virtual TQString host() = 0;
/**
* Returns the port the view is connected to.
@@ -130,7 +130,7 @@ public:
/**
* Returns the resolution of the remote framebuffer.
- * It should return a null @ref QSize when the size
+ * It should return a null @ref TQSize when the size
* is not known.
* The backend must also emit a @ref changeSize()